#
# Cookbook:: haproxy
# Recipe:: default
#
# Copyright:: 2009-2016, Chef Software, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

include_recipe 'build-essential'

case node['platform_family']
when 'debian'
  pcre_pkg = 'libpcre3-dev'
  ssl_pkg = 'libssl-dev'
  zlib_pkg = 'zlib1g-dev'
when 'rhel'
  pcre_pkg = 'pcre-devel'
  ssl_pkg = 'openssl-devel'
  zlib_pkg = 'zlib-devel'
end

package pcre_pkg do # ~FC005
  only_if { node['haproxy']['source']['use_pcre'] }
end

package ssl_pkg do
  only_if { node['haproxy']['source']['use_openssl'] }
end

package zlib_pkg do
  only_if { node['haproxy']['source']['use_zlib'] }
end

node.default['haproxy']['conf_dir'] = ::File.join(node['haproxy']['source']['prefix'], 'etc', 'haproxy')

download_file_path = ::File.join(Chef::Config[:file_cache_path], "haproxy-#{node['haproxy']['source']['version']}.tar.gz")
remote_file 'haproxy source file' do
  path download_file_path
  source node['haproxy']['source']['url']
  checksum node['haproxy']['source']['checksum']
  action :create
end

make_cmd = "make TARGET=#{node['haproxy']['source']['target_os']}"
make_cmd << " CPU=#{node['haproxy']['source']['target_cpu']}" unless node['haproxy']['source']['target_cpu'].empty?
make_cmd << " ARCH=#{node['haproxy']['source']['target_arch']}" unless node['haproxy']['source']['target_arch'].empty?
make_cmd << ' USE_PCRE=1' if node['haproxy']['source']['use_pcre']
make_cmd << ' USE_OPENSSL=1' if node['haproxy']['source']['use_openssl']
make_cmd << ' USE_ZLIB=1' if node['haproxy']['source']['use_zlib']
make_cmd << ' USE_LINUX_TPROXY=1' if node['haproxy']['source']['use_tproxy']
make_cmd << ' USE_LINUX_SPLICE=1' if node['haproxy']['source']['use_splice']
extra_cmd = 'EXTRA=haproxy-systemd-wrapper' if node['init_package'] == 'systemd'

bash 'compile_haproxy' do
  cwd Chef::Config[:file_cache_path]
  code <<-EOH
    tar xzf haproxy-#{node['haproxy']['source']['version']}.tar.gz
    cd haproxy-#{node['haproxy']['source']['version']}
    #{make_cmd} && make install PREFIX=#{node['haproxy']['source']['prefix']} #{extra_cmd}
  EOH
  not_if "#{node['haproxy']['source']['prefix']}/sbin/haproxy -v | grep #{node['haproxy']['source']['version']}"
end

directory node['haproxy']['conf_dir']
